"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../utils/constants");
require("isomorphic-fetch");
const cuid = require("cuid");
const open = require("open");
const debug = require('debug')('graphcool');
class GraphcoolAuthServer {
    requestAuthToken() {
        return __awaiter(this, void 0, void 0, function* () {
            const cliToken = cuid();
            yield fetch(`${constants_1.authEndpoint}/create`, {
                method: 'post',
                headers: {
                    "Content-Type": "application/json",
                },
                body: JSON.stringify({ cliToken }),
            });
            const frontend = 'https://cli-auth.graph.cool';
            open(`${frontend}/?token=${cliToken}`);
            while (true) {
                const result = yield fetch(`${constants_1.authEndpoint}/${cliToken}`);
                const json = yield result.json();
                const { authToken } = json;
                if (authToken) {
                    return authToken;
                }
            }
        });
    }
    validateAuthToken(token) {
        return __awaiter(this, void 0, void 0, function* () {
            const authQuery = `{
      viewer {
        user {
          id
          email
        }
      }
    }`;
            try {
                const result = yield fetch(constants_1.systemAPIEndpoint, {
                    method: 'POST',
                    headers: {
                        'Authorization': `Bearer ${token}`,
                        "Content-Type": "application/json",
                    },
                    body: JSON.stringify({ query: authQuery })
                });
                const json = yield result.json();
                if (!json.data.viewer.user || !json.data.viewer.user.email || json.errors) {
                    return undefined;
                }
                return json.data.viewer.user.email;
            }
            catch (e) {
                return undefined;
            }
        });
    }
}
exports.GraphcoolAuthServer = GraphcoolAuthServer;
//# sourceMappingURL=GraphcoolAuthServer.js.map