"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const file_1 = require("../utils/file");
const system_1 = require("../utils/system");
const constants_1 = require("../utils/constants");
const debug = require('debug')('graphcool-auth');
exports.default = (props, env, authServer) => __awaiter(this, void 0, void 0, function* () {
    const { resolver, out } = env;
    let token = props.token;
    if (!token) {
        out.startSpinner(constants_1.openBrowserMessage);
        yield system_1.sleep(500);
        try {
            token = yield authServer.requestAuthToken();
        }
        catch (e) {
            throw new Error(constants_1.couldNotRetrieveTokenMessage);
        }
        out.stopSpinner();
    }
    const authenticatedUserEmail = yield authServer.validateAuthToken(token);
    if (authenticatedUserEmail) {
        file_1.writeGraphcoolConfig({ token }, resolver);
        out.write(constants_1.authenticationSuccessMessage(authenticatedUserEmail));
    }
    else {
        file_1.deleteGraphcoolConfig(resolver);
        throw new Error('Invalid auth token');
    }
});
//# sourceMappingURL=auth.js.map