"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const file_1 = require("../utils/file");
const constants_1 = require("../utils/constants");
const api_1 = require("../api/api");
const debug = require('debug')('graphcool');
exports.default = (props, env) => __awaiter(this, void 0, void 0, function* () {
    const { resolver, out } = env;
    try {
        const projectId = getProjectId(props, resolver);
        if (!projectId) {
            throw new Error(constants_1.noProjectIdMessage);
        }
        out.startSpinner(constants_1.cloningProjectMessage);
        const includeMutationCallbacks = props.includeMutationCallbacks !== undefined ? props.includeMutationCallbacks : true;
        const includeData = props.includeData !== undefined ? props.includeData : true;
        const clonedProjectName = yield getClonedProjectName(props, projectId, resolver);
        const clonedProjectInfo = yield api_1.cloneProject(projectId, clonedProjectName, includeMutationCallbacks, includeData, resolver);
        const projectFile = props.projectFile || constants_1.graphcoolProjectFileName;
        const outputPath = props.outputPath || constants_1.graphcoolCloneProjectFileName(projectFile);
        file_1.writeProjectFile(clonedProjectInfo, resolver, outputPath);
        out.stopSpinner();
        const message = constants_1.clonedProjectMessage(clonedProjectName, outputPath, clonedProjectInfo.projectId);
        out.write(message);
    }
    catch (e) {
        out.stopSpinner();
        if (e.errors) {
            const errors = api_1.parseErrors(e);
            const output = api_1.generateErrorOutput(errors);
            out.writeError(`${output}`);
        }
        else {
            throw e;
        }
    }
});
function getClonedProjectName(props, projectId, resolver) {
    return __awaiter(this, void 0, void 0, function* () {
        if (props.name) {
            return Promise.resolve(props.name);
        }
        const projectInfo = yield api_1.pullProjectInfo(projectId, resolver);
        const clonedPojectName = `Clone of ${projectInfo.name}`;
        return clonedPojectName;
    });
}
function getProjectFilePath(props, resolver) {
    // check if provided file is valid (ends with correct suffix)
    if (props.projectFile && file_1.isValidProjectFilePath(props.projectFile)) {
        return props.projectFile;
    }
    else if (props.projectFile && !file_1.isValidProjectFilePath(props.projectFile)) {
        throw new Error(constants_1.invalidProjectFilePathMessage(props.projectFile));
    }
    // no project file provided, search for one in current dir
    const projectFiles = resolver.projectFiles('.');
    if (projectFiles.length === 0) {
        throw new Error(constants_1.noProjectFileOrIdMessage);
    }
    else if (projectFiles.length > 1) {
        throw new Error(constants_1.multipleProjectFilesForCloneMessage(projectFiles));
    }
    return projectFiles[0];
}
function getProjectId(props, resolver) {
    if (props.sourceProjectId) {
        return props.sourceProjectId;
    }
    const projectFile = getProjectFilePath(props, resolver);
    return file_1.readProjectIdFromProjectFile(resolver, projectFile);
}
//# sourceMappingURL=clone.js.map