"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const file_1 = require("../utils/file");
const constants_1 = require("../utils/constants");
const debug = require('debug')('graphcool');
exports.default = (props, env) => __awaiter(this, void 0, void 0, function* () {
    const { out } = env;
    const projectId = getProjectId(props, env);
    if (!projectId) {
        throw new Error(constants_1.noProjectIdMessage);
    }
    const message = constants_1.endpointsMessage(projectId);
    out.write(message);
});
function getProjectId(props, env) {
    const { resolver } = env;
    // check if provided file is valid (ends with correct suffix)
    if (props.projectFile && file_1.isValidProjectFilePath(props.projectFile)) {
        return file_1.readProjectIdFromProjectFile(resolver, props.projectFile);
    }
    else if (props.projectFile && !file_1.isValidProjectFilePath(props.projectFile)) {
        throw new Error(constants_1.invalidProjectFilePathMessage(props.projectFile));
    }
    // no project file provided, search for one in current dir
    const projectFiles = resolver.projectFiles('.');
    if (projectFiles.length === 0) {
        throw new Error(constants_1.noProjectFileMessage);
    }
    else if (projectFiles.length > 1) {
        throw new Error(constants_1.multipleProjectFilesForExportMessage(projectFiles));
    }
    return file_1.readProjectIdFromProjectFile(resolver, projectFiles[0]);
}
//# sourceMappingURL=endpoints.js.map