"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const generateName = require("sillyname");
const api_1 = require("../api/api");
const fs = require("fs");
const path = require("path");
const utils_1 = require("../utils/utils");
const file_1 = require("../utils/file");
require("isomorphic-fetch");
const constants_1 = require("../utils/constants");
const debug = require('debug')('graphcool');
exports.default = (props, env) => __awaiter(this, void 0, void 0, function* () {
    const { resolver, out } = env;
    if (resolver.exists(constants_1.graphcoolProjectFileName) && resolver.read(constants_1.graphcoolProjectFileName).toString().includes('# project:')) {
        throw new Error(constants_1.projectAlreadyExistsMessage);
    }
    const name = props.name || generateName();
    out.startSpinner(constants_1.creatingProjectMessage(name));
    try {
        // resolve schema
        const schemaUrl = props.localSchemaFile ? props.localSchemaFile : props.remoteSchemaUrl;
        if (!file_1.isValidSchemaFilePath(schemaUrl)) {
            throw new Error(constants_1.invalidSchemaFileMessage(schemaUrl));
        }
        const schema = yield getSchema(schemaUrl, resolver);
        // create project
        const projectInfo = yield createProjectAndGetProjectInfo(name, schema, resolver, props.alias, props.region);
        file_1.writeProjectFile(projectInfo, resolver, props.outputPath);
        out.stopSpinner();
        const message = constants_1.createdProjectMessage(name, projectInfo.projectId, utils_1.projectInfoToContents(projectInfo));
        out.write(message);
    }
    catch (e) {
        out.stopSpinner();
        out.writeError(`${constants_1.couldNotCreateProjectMessage}`);
        if (e.errors) {
            const errors = api_1.parseErrors(e);
            const output = api_1.generateErrorOutput(errors);
            out.writeError(`${output}`);
        }
        else {
            throw e;
        }
    }
});
function createProjectAndGetProjectInfo(name, schema, resolver, alias, region) {
    return __awaiter(this, void 0, void 0, function* () {
        const projectInfo = yield api_1.createProject(name, schema.schema, resolver, alias, region);
        if (schema.source === constants_1.sampleSchemaURL) {
            projectInfo.schema = `${projectInfo.schema}\n\n# type Tweet {\n#   text: String!\n# }`;
        }
        return projectInfo;
    });
}
function getSchema(schemaUrl, resolver) {
    return __awaiter(this, void 0, void 0, function* () {
        if (schemaUrl) {
            if (schemaUrl.startsWith('http')) {
                const response = yield fetch(schemaUrl);
                const schema = yield response.text();
                return {
                    schema,
                    source: schemaUrl,
                };
            }
            else {
                return {
                    schema: resolver.read(schemaUrl),
                    source: schemaUrl,
                };
            }
        }
        else {
            const schemaFiles = resolver.readDirectory('.').filter(f => f.endsWith(constants_1.projectFileSuffix));
            if (schemaFiles.length === 0) {
                throw new Error(`No ${constants_1.projectFileSuffix} file found or specified`);
            }
            const file = schemaFiles.find(f => f === constants_1.graphcoolProjectFileName) || schemaFiles[0];
            return {
                schema: fs.readFileSync(path.resolve(file)).toString(),
                source: schemaFiles[0],
            };
        }
    });
}
//# sourceMappingURL=init.js.map