"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const file_1 = require("../utils/file");
const api_1 = require("../api/api");
const open = require("open");
const constants_1 = require("../utils/constants");
const debug = require('debug')('graphcool-auth');
exports.default = (props, env) => __awaiter(this, void 0, void 0, function* () {
    const { resolver, out } = env;
    const { token } = file_1.readGraphcoolConfig(resolver);
    if (!token) {
        throw new Error(constants_1.notAuthenticatedMessage);
    }
    const projectInfo = yield getProjectInfo(props, env);
    const url = constants_1.playgroundURL(token, projectInfo.name);
    open(url);
    out.write(constants_1.openedPlaygroundMessage(projectInfo.name));
});
function getProjectInfo(props, env) {
    return __awaiter(this, void 0, void 0, function* () {
        const currentProjectId = getProjectId(props, env);
        if (!currentProjectId) {
            throw new Error(constants_1.canNotReadProjectIdFromProjectFile);
        }
        const projectInfo = yield api_1.pullProjectInfo(currentProjectId, env.resolver);
        return projectInfo;
    });
}
function getProjectId(props, env) {
    const { resolver } = env;
    // check if provided file is valid (ends with correct suffix)
    if (props.projectFile && file_1.isValidProjectFilePath(props.projectFile)) {
        return file_1.readProjectIdFromProjectFile(resolver, props.projectFile);
    }
    else if (props.projectFile && !file_1.isValidProjectFilePath(props.projectFile)) {
        throw new Error(constants_1.invalidProjectFilePathMessage(props.projectFile));
    }
    // no project file provided, search for one in current dir
    const projectFiles = resolver.projectFiles('.');
    if (projectFiles.length === 0) {
        return undefined;
    }
    else if (projectFiles.length > 1) {
        throw new Error(constants_1.tooManyProjectFilesForPlaygroundMessage(projectFiles));
    }
    return file_1.readProjectIdFromProjectFile(resolver, projectFiles[0]);
}
//# sourceMappingURL=playground.js.map