"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const api_1 = require("../api/api");
const constants_1 = require("../utils/constants");
const file_1 = require("../utils/file");
const { table, getBorderCharacters } = require('table');
const debug = require('debug')('graphcool');
exports.default = (props, env) => __awaiter(this, void 0, void 0, function* () {
    const { resolver, out } = env;
    try {
        const projects = yield api_1.fetchProjects(resolver);
        const currentProjectId = resolver.exists(constants_1.graphcoolProjectFileName) ?
            file_1.readProjectIdFromProjectFile(resolver, constants_1.graphcoolProjectFileName) :
            null;
        const data = projects.map(project => {
            const isCurrentProject = currentProjectId !== null && (currentProjectId === project.projectId || currentProjectId === project.alias);
            return [isCurrentProject ? '*' : ' ', `${project.alias || project.projectId}   `, project.name];
        });
        const output = table(data, {
            border: getBorderCharacters('void'),
            columnDefault: {
                paddingLeft: '0',
                paddingRight: '1',
            },
            drawHorizontalLine: () => false,
        }).trimRight();
        out.write(output);
    }
    catch (e) {
        throw new Error(`${constants_1.couldNotFetchProjectsMessage} ${e.message}`);
    }
});
//# sourceMappingURL=projects.js.map