"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const file_1 = require("../utils/file");
const api_1 = require("../api/api");
const constants_1 = require("../utils/constants");
var term = require('terminal-kit').terminal;
const debug = require('debug')('graphcool');
exports.default = (props, env) => __awaiter(this, void 0, void 0, function* () {
    const { resolver, out } = env;
    try {
        const projectId = getProjectId(props, env);
        const projectFile = props.projectFile || constants_1.graphcoolProjectFileName;
        const outputPath = props.outputPath || projectFile;
        const currentVersion = getCurrentVersion(projectFile, resolver);
        if (!projectId) {
            throw new Error(constants_1.noProjectIdMessage);
        }
        // warn if the current project file is different from specified project id
        if (resolver.exists(constants_1.graphcoolProjectFileName)) {
            const readProjectId = file_1.readProjectIdFromProjectFile(resolver, constants_1.graphcoolProjectFileName);
            if (readProjectId && projectId !== readProjectId) {
                out.write(constants_1.differentProjectIdWarningMessage(projectId, readProjectId));
                term.grabInput(true);
                yield new Promise(resolve => {
                    term.on('key', function (name) {
                        if (name !== 'y') {
                            process.exit(0);
                        }
                        term.grabInput(false);
                        resolve();
                    });
                });
            }
        }
        if (!props.force && projectFile === outputPath) {
            out.write(constants_1.warnOverrideProjectFileMessage(projectFile));
            term.grabInput(true);
            yield new Promise(resolve => {
                term.on('key', function (name) {
                    if (name !== 'y') {
                        process.exit(0);
                    }
                    term.grabInput(false);
                    resolve();
                });
            });
        }
        out.startSpinner(`${constants_1.fetchingProjectDataMessage}`);
        const projectInfo = yield api_1.pullProjectInfo(projectId, resolver);
        out.stopSpinner();
        const message = resolver.projectFiles('.').length === 0 ?
            constants_1.pulledInitialProjectFileMessage(outputPath) :
            constants_1.wroteProjectFileMessage(outputPath);
        file_1.writeProjectFile(projectInfo, resolver, outputPath);
        out.write(message);
        if (projectInfo.version && currentVersion) {
            const shouldDisplayVersionUpdate = parseInt(projectInfo.version) > parseInt(currentVersion);
            if (shouldDisplayVersionUpdate) {
                const message = constants_1.newVersionMessage(projectInfo.version);
                out.write(` ${message}`);
            }
        }
    }
    catch (e) {
        out.stopSpinner();
        if (e.errors) {
            const errors = api_1.parseErrors(e);
            const output = api_1.generateErrorOutput(errors);
            out.writeError(`${output}`);
        }
        else {
            throw e;
        }
    }
});
function getProjectFilePath(props, env) {
    const { resolver, out } = env;
    // check if provided file is valid (ends with correct suffix)
    if (props.projectFile && file_1.isValidProjectFilePath(props.projectFile)) {
        return props.projectFile;
    }
    else if (props.projectFile && !file_1.isValidProjectFilePath(props.projectFile)) {
        throw new Error(constants_1.invalidProjectFilePathMessage(props.projectFile));
    }
    // no project file provided, search for one in current dir
    const projectFiles = resolver.projectFiles('.');
    if (projectFiles.length === 0) {
        throw new Error(constants_1.noProjectFileForPullMessage);
    }
    else if (projectFiles.length > 1) {
        throw new Error(constants_1.multipleProjectFilesForPullMessage(projectFiles));
    }
    return projectFiles[0];
}
function getProjectId(props, env) {
    if (props.sourceProjectId) {
        return props.sourceProjectId;
    }
    const projectFile = getProjectFilePath(props, env);
    return file_1.readProjectIdFromProjectFile(env.resolver, projectFile);
}
function getCurrentVersion(path, resolver) {
    if (resolver.exists(path)) {
        return file_1.readVersionFromProjectFile(resolver, path);
    }
    return undefined;
}
//# sourceMappingURL=pull.js.map