#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const minimist = require("minimist");
const push_1 = require("./commands/push");
const console_1 = require("./commands/console");
const clone_1 = require("./commands/clone");
const playground_1 = require("./commands/playground");
const projects_1 = require("./commands/projects");
const pull_1 = require("./commands/pull");
const auth_1 = require("./commands/auth");
const init_1 = require("./commands/init");
const interactiveInit_1 = require("./commands/interactiveInit");
const export_1 = require("./commands/export");
const endpoints_1 = require("./commands/endpoints");
const status_1 = require("./commands/status");
const FileSystemResolver_1 = require("./system/FileSystemResolver");
const StdOut_1 = require("./system/StdOut");
const GraphcoolAuthServer_1 = require("./api/GraphcoolAuthServer");
const file_1 = require("./utils/file");
const constants_1 = require("./utils/constants");
const usage_1 = require("./utils/usage");
var Raven = require('raven');
const debug = require('debug')('graphcool');
const { version } = require('../../package.json');
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        // initialize sentry
        Raven.config(`https://${constants_1.sentryKey}@sentry.io/${constants_1.sentryId}`).install();
        const argv = minimist(process.argv.slice(2));
        const command = argv._[0];
        switch (command) {
            case undefined: {
                process.stdout.write(usage_1.usageRoot);
                process.exit(0);
            }
            // TODO remove legacy support
            case 'create': {
                checkHelp(argv, usage_1.usageInit);
                yield checkAuth();
                const name = argv['name'] || argv['n'];
                const alias = argv['alias'] || argv['a'];
                const region = argv['region'] || argv['r'];
                const schemaUrl = argv._[1];
                const remoteSchemaUrl = schemaUrl;
                const localSchemaFile = schemaUrl;
                const props = { name, alias, remoteSchemaUrl, localSchemaFile, region };
                yield init_1.default(props, defaultEnvironment());
                break;
            }
            case 'init': {
                checkHelp(argv, usage_1.usageInit);
                const name = argv['name'] || argv['n'];
                const alias = argv['alias'] || argv['a'];
                const region = argv['region'] || argv['r'];
                const remoteSchemaUrl = argv['url'] || argv['u'];
                const localSchemaFile = argv['file'] || argv['f'];
                const outputPath = argv['output'] || argv['o'];
                if (!remoteSchemaUrl && !localSchemaFile) {
                    const props = { name, alias, outputPath, checkAuth };
                    yield interactiveInit_1.default(props, defaultEnvironment());
                }
                else {
                    yield checkAuth();
                    const props = { name, alias, remoteSchemaUrl, localSchemaFile, region, outputPath };
                    yield init_1.default(props, defaultEnvironment());
                }
                break;
            }
            case 'clone': {
                checkHelp(argv, usage_1.usageClone);
                yield checkAuth();
                const name = argv['name'] || argv['n'];
                const sourceProjectId = argv['source'] || argv['s'];
                const projectFile = (argv['project'] || argv['p']);
                const outputPath = argv['output'] || argv['o'];
                const includes = argv['include'] || argv['i'];
                const includeMutationCallbacks = includes === 'all' || includes === 'mutation-callbacks';
                const includeData = includes === 'all' || includes === 'data';
                const props = {
                    sourceProjectId,
                    projectFile,
                    outputPath,
                    name,
                    includeMutationCallbacks,
                    includeData
                };
                yield clone_1.default(props, defaultEnvironment());
                break;
            }
            case 'push': {
                checkHelp(argv, usage_1.usagePush);
                yield checkAuth();
                const force = !!(argv['force'] || argv['f']);
                const projectFile = (argv['project'] || argv['p']);
                yield push_1.default({ force, projectFile }, defaultEnvironment());
                break;
            }
            case 'pull': {
                checkHelp(argv, usage_1.usagePull);
                yield checkAuth();
                const sourceProjectId = argv['source'] || argv['s'];
                const projectFile = argv['project'] || argv['p'];
                const outputPath = argv['output'] || argv['o'];
                const force = !!(argv['force'] || argv['f']);
                yield pull_1.default({ sourceProjectId, projectFile, outputPath, force }, defaultEnvironment());
                break;
            }
            case 'export': {
                checkHelp(argv, usage_1.usageExport);
                yield checkAuth();
                const projectFile = argv['project'] || argv['p'];
                yield export_1.default({ projectFile }, defaultEnvironment());
                break;
            }
            case 'status': {
                checkHelp(argv, usage_1.usageStatus);
                yield checkAuth();
                const projectFile = argv['project'] || argv['p'];
                yield status_1.default({ projectFile }, defaultEnvironment());
                break;
            }
            case 'endpoints': {
                checkHelp(argv, usage_1.usageEndpoints);
                yield checkAuth();
                const projectFile = argv['project'] || argv['p'];
                yield endpoints_1.default({ projectFile }, defaultEnvironment());
                break;
            }
            case 'console': {
                checkHelp(argv, usage_1.usageConsole);
                yield checkAuth();
                const projectFile = argv['project'] || argv['p'];
                yield console_1.default({ projectFile }, defaultEnvironment());
                break;
            }
            case 'playground': {
                checkHelp(argv, usage_1.usagePlayground);
                yield checkAuth();
                const projectFile = argv['project'] || argv['p'];
                yield playground_1.default({ projectFile }, defaultEnvironment());
                break;
            }
            case 'projects': {
                checkHelp(argv, usage_1.usageProjects);
                yield checkAuth();
                yield projects_1.default({}, defaultEnvironment());
                break;
            }
            case 'auth': {
                checkHelp(argv, usage_1.usageAuth);
                const token = argv['token'] || argv['t'];
                yield auth_1.default({ token }, defaultEnvironment(), new GraphcoolAuthServer_1.GraphcoolAuthServer());
                break;
            }
            case 'help': {
                process.stdout.write(usage_1.usageRoot);
                process.exit(0);
                break;
            }
            case 'version': {
                checkHelp(argv, usage_1.usageVersion);
                process.stdout.write(version);
                break;
            }
            default: {
                process.stdout.write(`Unknown command: ${command}\n\n${usage_1.usageRoot}`);
                break;
            }
        }
        process.stdout.write('\n');
    });
}
function checkAuth() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            file_1.readGraphcoolConfig(new FileSystemResolver_1.default());
        }
        catch (e) {
            yield auth_1.default({}, defaultEnvironment(), new GraphcoolAuthServer_1.GraphcoolAuthServer());
        }
    });
}
function checkHelp(argv, usage) {
    if (argv['help'] || argv['h']) {
        process.stdout.write(usage);
        process.exit(0);
    }
}
function defaultEnvironment() {
    return {
        resolver: new FileSystemResolver_1.default(),
        out: new StdOut_1.default()
    };
}
process.on('unhandledRejection', e => new StdOut_1.default().onError(e));
main();
//# sourceMappingURL=index.js.map