"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ora = require("ora");
const chalk = require("chalk");
const constants_1 = require("../utils/constants");
const figures = require("figures");
const utils_1 = require("../utils/utils");
var Raven = require('raven');
const debug = require('debug')('graphcool');
class StdOut {
    write(message) {
        process.stdout.write(message);
    }
    writeError(message) {
        process.stderr.write(message);
    }
    startSpinner(message) {
        this.spinner = ora(message).start();
    }
    stopSpinner() {
        if (this.spinner) {
            this.spinner.stop();
        }
    }
    onError(error) {
        Raven.captureException(error);
        console.log(`Caught Error: ${JSON.stringify(error)}`);
        // prevent the same error output twice
        const errorMessage = utils_1.makePartsEnclodesByCharacterBold(`Error: ${error.message}`, `\``);
        if (error.stack && !error.stack.startsWith(errorMessage)) {
            console.error(`${chalk.red(figures.cross)}  ${errorMessage}`);
            debug(error.stack);
        }
        else {
            const errorLines = error.stack.split('\n');
            const firstErrorLine = errorLines[0];
            console.error(`${chalk.red(figures.cross)}  ${firstErrorLine}`);
            debug(error.stack);
        }
        console.error(`\n${constants_1.setDebugMessage}\n${constants_1.contactUsInSlackMessage}\n`);
        process.exit(1);
    }
}
exports.default = StdOut;
//# sourceMappingURL=StdOut.js.map