"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../utils/constants");
class TestResolver {
    constructor(storage) {
        this.storage = storage;
    }
    read(path) {
        // absolute path
        if (path.startsWith('/')) {
            return this.storage[path];
        }
        // prepend ./ if necessary
        if (!path.startsWith('./')) {
            path = `./${path}`;
        }
        return this.storage[path];
    }
    write(path, value) {
        // absolute path
        if (path.startsWith('/')) {
            this.storage[path] = value;
            return;
        }
        // prepend ./ if necessary
        if (!path.startsWith('./')) {
            path = `./${path}`;
        }
        this.storage[path] = value;
    }
    delete(path) {
        // absolute path
        if (path.startsWith('/')) {
            delete this.storage[path];
            return;
        }
        // prepend ./ if necessary
        if (!path.startsWith('./')) {
            path = `./${path}`;
        }
        delete this.storage[path];
    }
    exists(path) {
        return (typeof (this.storage[path]) !== 'undefined') || (typeof (this.storage[`./${path}`]) !== 'undefined');
    }
    projectFiles(directory) {
        const path = directory || '.';
        const files = this.readDirectory(path);
        return files.filter(file => file.endsWith(constants_1.projectFileSuffix));
    }
    schemaFiles(directory) {
        const path = directory || '.';
        const files = this.readDirectory(path);
        return files.filter(file => file.endsWith(constants_1.schemaFileSuffix));
    }
    readDirectory(path) {
        const paths = Object.keys(this.storage);
        return paths.filter(fullPath => fullPath.startsWith(path));
    }
}
exports.default = TestResolver;
//# sourceMappingURL=TestResolver.js.map