"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const os = require("os");
const path = require("path");
const chalk = require("chalk");
const figures = require("figures");
/*
 * Networking & URLs
 */
exports.systemAPIEndpoint = 'https://api.graph.cool/system';
exports.authEndpoint = 'https://cli-auth-api.graph.cool';
exports.consoleURL = (token, projectName) => `https://console.graph.cool/token/?token=${token}${projectName ? `&redirect=/${encodeURIComponent(projectName)}` : ''}`;
exports.playgroundURL = (token, projectName) => `https://console.graph.cool/token/?token=${token}&redirect=/${encodeURIComponent(projectName)}/playground`;
exports.sampleSchemaURL = `http://graphqlbin.com/empty.graphql`;
/*
 * Sentry
 */
// DSN: https:df8b750d27504597af166dc757a890ed//@sentry.io/165377
exports.sentryKey = 'df8b750d27504597af166dc757a890ed';
exports.sentryId = '165377';
/*
 * File paths / names
 */
exports.graphcoolProjectFileName = 'project.graphcool';
exports.graphcoolCloneProjectFileName = (projectFileName) => projectFileName ?
    `clone-${projectFileName.startsWith(`./`) ? projectFileName.substring(2) : projectFileName}` : `clone-${exports.graphcoolProjectFileName}`;
exports.graphcoolConfigFilePath = path.join(os.homedir(), '.graphcool');
exports.projectFileSuffix = '.graphcool';
exports.schemaFileSuffix = '.graphql';
exports.instagramExampleSchemaUrl = 'http://graphqlbin.com/instagram.graphql';
exports.exampleSchema = `\
type User {
  id: ID!
}

# type Tweet {
#   text: String!
# }`;
/*
 * Terminal output: auth
 */
exports.openBrowserMessage = `You need to authenticate. Your browser will open shortly...`;
exports.couldNotRetrieveTokenMessage = `\
Whoops, something went wrong during authentication.
`;
exports.authenticationSuccessMessage = (email) => ` ${chalk.green(figures.tick)} Authenticated user: ${chalk.bold(email)}
`;
/*
 * Terminal output: create
 */
exports.creatingProjectMessage = (name) => `Creating project ${chalk.bold(name)}...`;
exports.createdProjectMessage = (name, projectId, projectFileContent) => `\
 ${chalk.green(figures.tick)} Created project ${chalk.bold(name)} (ID: ${projectId}) successfully.
 
 
   ${chalk.bold('Here is what you can do next:')}

   1) Open ${chalk.bold('project.graphcool')} in your editor to update your schema.
      You can push your changes using ${chalk.cyan('`graphcool push`')}.
      
   2) Use one of the following endpoints to connect to your GraphQL API:
 
        Simple API:   https://api.graph.cool/simple/v1/${projectId}
        Relay API:    https://api.graph.cool/relay/v1/${projectId}
      
   3) Read more about the CLI workflow in the docs: ${chalk.underline('https://www.graph.cool/docs/reference/cli')}
`;
exports.couldNotCreateProjectMessage = `\
Whoops, something went wrong while creating the project.
`;
exports.projectAlreadyExistsMessage = `\
${exports.graphcoolProjectFileName} already exists for the current project. \
Looks like you've already setup your backend.
`;
exports.howDoYouWantToGetStarted = () => `\

  You are about to create a new Graphcool project. 


  ${chalk.bold('How do you want to continue?')}

`;
exports.invalidSchemaFileMessage = (schemaFileName) => `\
Your schema file ${chalk.bold(schemaFileName)} is invalid. A schema file must end with ${chalk.bold(exports.schemaFileSuffix)}.
`;
/*
 * Terminal output: push
 */
exports.remoteSchemaAheadMessage = (remoteVersion, localVersion) => `\
The local version of your schema (${localVersion}) is behind the remote version (${remoteVersion}). Save your local changes and pull before retrying.
`;
exports.noProjectFileForPushMessage = `\
Please provide a valid project file (${exports.graphcoolProjectFileName}) for the schema migration.
`;
exports.invalidProjectFileMessage = `\
The project file (${exports.graphcoolProjectFileName}) that you provided doesn't seem to be valid. Please make sure it contains the ID of your project.
`;
exports.pushingNewSchemaMessage = `\
Migrating the schema in your project...`;
exports.couldNotMigrateSchemaMessage = `
An error occured while trying to migrate the project.
`;
exports.noActionRequiredMessage = `\
 ${chalk.green(figures.tick)} Identical schema, no action required.
`;
exports.migrationPerformedMessage = `\
 ${chalk.green(figures.tick)} Your schema was successfully updated. Here are the changes:
`;
exports.migrationErrorMessage = `\
There are issues with the new schema that you provided:
`;
exports.invalidProjectFilePathMessage = (projectFilePath) => `\
${projectFilePath} is not a valid project file (must end with ${exports.projectFileSuffix}).
`;
exports.multipleProjectFilesMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one you want to push, e.g.: ${chalk.cyan(`\`graphcool push -p ${projectFiles[0]}\``)}
`;
/*
 * Terminal output: projects
 */
exports.couldNotFetchProjectsMessage = `\
An error occured while trying to fetch your projects.
`;
/*
 * Terminal output: endpoints
 */
exports.endpointsMessage = (projectId) => `\
 The endpoints for your project are are:
 
   ${chalk.blue(figures.pointer)} Simple API: https://api.graph.cool/simple/v1/${projectId}
   ${chalk.blue(figures.pointer)} Relay API: https://api.graph.cool/relay/v1/${projectId}
`;
/*
 * Terminal output: pull
 */
exports.fetchingProjectDataMessage = `\
Fetching project data ...`;
exports.noProjectFileForPullMessage = `\
There is no project file (project.graphcool) in the current directory.
`;
exports.noProjectIdMessage = `\
Please provide a valid project ID.
`;
exports.wroteProjectFileMessage = (projectFile) => `\
 ${chalk.green(figures.tick)} Your project file (${chalk.bold(projectFile)}) was successfully updated. Reload it in your editor if needed. `;
exports.pulledInitialProjectFileMessage = (projectFile) => `\
 ${chalk.green(figures.tick)} Your project file was written to ${chalk.bold(projectFile)}`;
exports.newVersionMessage = (newVersion) => `\
The new schema version is ${chalk.bold(newVersion)}.
`;
exports.differentProjectIdWarningMessage = (inputProjectId, readProjectId) => `\
The project ID you provided (${inputProjectId}) is different than the one in the current project file (${readProjectId}). 
This will override the current project file with a different project, do you still want to continue? [y|n]
`;
exports.warnOverrideProjectFileMessage = (projectFile) => `\
You are about to override the local project file ${chalk.bold(projectFile)}. Make sure to save local changes that you want to preserve.
Do you want to continue? [y|n]
`;
exports.multipleProjectFilesForPullMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one you want for which you want to pull the new schema, e.g.: ${chalk.cyan(`\`graphcool pull -p ${projectFiles[0]}\``)}
`;
/*
 * Terminal output: export
 */
exports.exportingDataMessage = `\
Exporting your project data ...`;
exports.downloadUrlMessage = (url) => `\
 ${chalk.green(figures.tick)} You can download your project data by pasting this URL in a browser:

   ${chalk.blue(figures.pointer)} Download URL: ${url}
`;
exports.multipleProjectFilesForExportMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one you for which you want to export the data, e.g.: ${chalk.cyan(`\`graphcool export -p ${projectFiles[0]}\``)}
`;
/*
 * Terminal output: console
 */
exports.openedConsoleMessage = (projectName) => projectName ? `\
The Console for project ${chalk.bold(projectName)} was opened in your browser.
` : `\
The Console was opened in your browser.
`;
/*
 * Terminal output: clone
 */
exports.multipleProjectFilesForCloneMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one for which you want to clone the project, e.g.: ${chalk.cyan(`\`graphcool clone -p ${projectFiles[0]}\``)}
`;
exports.cloningProjectMessage = `\
Cloning your project ...`;
exports.clonedProjectMessage = (clonedProjectName, outputPath, projectId) => `\
 ${chalk.green(figures.tick)} Cloned your project as ${chalk.bold(clonedProjectName)}. The project file was written to ${chalk.bold(outputPath)}.
 
   Here are your endpoints: 
   
        Simple API:   https://api.graph.cool/simple/v1/${projectId}
        Relay API:    https://api.graph.cool/relay/v1/${projectId}  
`;
/*
 * Terminal output: playground
 */
exports.tooManyProjectFilesForPlaygroundMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one you for which you want open the Playground, e.g.: ${chalk.cyan(`\`graphcool playground -p ${projectFiles[0]}\``)}
`;
exports.openedPlaygroundMessage = (projectName) => `\
The Playground for project ${chalk.bold(projectName)} was opened in your browser.
`;
/*
 * Terminal output: status
 */
exports.multipleProjectFilesForStatusMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one you for which you want display the status, e.g.: ${chalk.cyan(`\`graphcool status -p ${projectFiles[0]}\``)}
`;
exports.localSchemaBehindRemoteMessage = (remoteVersion, localVersion) => `\
The local version of your schema (${localVersion}) is behind the remote version (${remoteVersion}). 
Save your local changes and execute 'graphcool pull' before a schema migration.
`;
exports.remoteSchemaBehindLocalMessage = (remoteVersion, localVersion) => `\
There is an issue with your schema. The remote version (${remoteVersion}) is behind the local version (${localVersion}). 
`;
exports.everythingUpToDateMessage = `\
Everything up-to-date.
`;
exports.potentialChangesMessage = `\
Here are all the actions to be taken for a schema migration: 
`;
exports.issuesInSchemaMessage = `\
The current version of your schema contains some issues: 
`;
/*
 * Terminal output: general
 */
exports.contactUsInSlackMessage = `\
 * Get in touch if you need help: http://slack.graph.cool/`;
exports.setDebugMessage = `\
 * You can enable additional output by setting \`export DEBUG=graphcool\` and rerunning the command.
 * Open an issue on GitHub: https://github.com/graphcool/graphcool-cli.`;
exports.noProjectFileOrIdMessage = `\
No project file or project ID provided.
`;
exports.noProjectFileMessage = `\
No project file found.
`;
exports.notAuthenticatedMessage = `\
You're currently not logged in. You can use the auth command to authenticate with ${chalk.cyan(`\`graphcool auth\``)}
`;
exports.projectFileWasUpdatedMessage = `\
Your project file was updated. Reload it in your editor if needed.
`;
exports.canNotReadVersionFromProjectFile = (projectFile) => `\
No schema version specified in ${chalk.bold(projectFile)}.
`;
exports.canNotReadProjectIdFromProjectFile = `\
Could not read the project's ID from project file.
`;
//# sourceMappingURL=constants.js.map