"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const constants_1 = require("./constants");
const debug = require('debug')('graphcool');
/*
 * Project File (.../project.graphcool)
 */
function writeProjectFile(projectInfo, resolver, path) {
    path = isValidProjectFilePath(path) ? path : constants_1.graphcoolProjectFileName;
    resolver.write(path, utils_1.projectInfoToContents(projectInfo));
}
exports.writeProjectFile = writeProjectFile;
function readProjectInfoFromProjectFile(resolver, path) {
    const projectId = readProjectIdFromProjectFile(resolver, path);
    if (!projectId) {
        return undefined;
    }
    const version = readVersionFromProjectFile(resolver, path);
    const schema = readDataModelFromProjectFile(resolver, path);
    return { projectId, version, schema };
}
exports.readProjectInfoFromProjectFile = readProjectInfoFromProjectFile;
function readProjectIdFromProjectFile(resolver, path) {
    const contents = resolver.read(path);
    const matches = contents.match(/# project: ([a-z0-9]*)/);
    if (!matches || matches.length !== 2) {
        return undefined;
    }
    return matches[1];
}
exports.readProjectIdFromProjectFile = readProjectIdFromProjectFile;
function readVersionFromProjectFile(resolver, path) {
    const contents = resolver.read(path);
    const matches = contents.match(/# version: ([a-z0-9]*)/);
    if (!matches || matches.length !== 2) {
        return undefined;
    }
    return matches[1];
}
exports.readVersionFromProjectFile = readVersionFromProjectFile;
function readDataModelFromProjectFile(resolver, path) {
    const contents = resolver.read(path);
    const dataModelStartIndex = contents.indexOf(`type`);
    const dataModel = contents.substring(dataModelStartIndex, contents.length);
    return dataModel;
}
exports.readDataModelFromProjectFile = readDataModelFromProjectFile;
function isValidProjectFilePath(projectFilePath) {
    if (!projectFilePath) {
        return false;
    }
    return projectFilePath.endsWith(constants_1.projectFileSuffix);
}
exports.isValidProjectFilePath = isValidProjectFilePath;
function isValidSchemaFilePath(schemaFilePath) {
    if (!schemaFilePath) {
        return false;
    }
    return schemaFilePath.endsWith(constants_1.schemaFileSuffix);
}
exports.isValidSchemaFilePath = isValidSchemaFilePath;
function writeExampleSchemaFile(resolver) {
    const path = 'example.graphql';
    resolver.write(path, constants_1.exampleSchema);
    return path;
}
exports.writeExampleSchemaFile = writeExampleSchemaFile;
/*
 * Graphcool Config (~/.graphcool)
 */
function readGraphcoolConfig(resolver) {
    const configFileContent = resolver.read(constants_1.graphcoolConfigFilePath);
    return JSON.parse(configFileContent);
}
exports.readGraphcoolConfig = readGraphcoolConfig;
function writeGraphcoolConfig(config, resolver) {
    resolver.write(constants_1.graphcoolConfigFilePath, JSON.stringify(config, null, 2));
}
exports.writeGraphcoolConfig = writeGraphcoolConfig;
function deleteGraphcoolConfig(resolver) {
    resolver.delete(constants_1.graphcoolConfigFilePath);
}
exports.deleteGraphcoolConfig = deleteGraphcoolConfig;
//# sourceMappingURL=file.js.map