"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const TestResolver_1 = require("../src/system/TestResolver");
const auth_1 = require("../src/commands/auth");
const constants_1 = require("../src/utils/constants");
const TestAuthServer_1 = require("../src/api/TestAuthServer");
const mockData_1 = require("./mock_data/mockData");
const TestOut_1 = require("../src/system/TestOut");
require("isomorphic-fetch");
const fetchMock = require('fetch-mock');
const debug = require('debug')('graphcool');
/*
 Tests:
 - Succeeding auth without token
 - Succeeding auth with existing token
 */
ava_1.default.afterEach(() => {
    fetchMock.restore();
});
ava_1.default('Succeeding auth without token', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(`${constants_1.authEndpoint}/create`, {});
    fetchMock.get(`${constants_1.authEndpoint}/*`, {
        authToken: mockData_1.testToken
    });
    fetchMock.post(`${constants_1.systemAPIEndpoint}`, {
        data: {
            viewer: {
                user: {
                    id: 'abcdefghik'
                }
            }
        }
    });
    // configure auth dependencies
    const env = testEnvironment({});
    const authServer = new TestAuthServer_1.default();
    env.out.prefix(t._test.title, '$ graphcool auth');
    // authenticate
    yield t.notThrows(auth_1.default({}, env, authServer));
    // verify result
    const { token } = JSON.parse(env.resolver.read(constants_1.graphcoolConfigFilePath));
    t.is(token, mockData_1.testToken);
}));
ava_1.default('Succeeding auth with existing token', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(`${constants_1.systemAPIEndpoint}`, {
        data: {
            viewer: {
                user: {
                    id: 'abcdefghik'
                }
            }
        }
    });
    // configure auth dependencies
    const props = { token: mockData_1.testToken };
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, mockData_1.testToken);
    const authServer = new TestAuthServer_1.default();
    env.out.prefix(t._test.title, `$ graphcool auth -t ${mockData_1.testToken}`);
    // authenticate
    yield t.notThrows(auth_1.default(props, env, authServer));
    // verify result
    const { token } = JSON.parse(env.resolver.read(constants_1.graphcoolConfigFilePath));
    t.is(token, mockData_1.testToken);
}));
function testEnvironment(storage) {
    return {
        resolver: new TestResolver_1.default(storage),
        out: new TestOut_1.default(),
    };
}
//# sourceMappingURL=auth.test.js.map