"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const TestResolver_1 = require("../src/system/TestResolver");
const clone_1 = require("../src/commands/clone");
const constants_1 = require("../src/utils/constants");
const mockData_1 = require("./mock_data/mockData");
require("isomorphic-fetch");
const file_1 = require("../src/utils/file");
const TestOut_1 = require("../src/system/TestOut");
const fetchMock = require('fetch-mock');
const debug = require('debug')('graphcool');
/*
 Tests:
- Succeeding project clone with specific name
- Succeeding project clone with specific name and different output path
- Succeeding project clone with specific name and project ID
- Succeeding project clone with specific name, project file and output path
- Failing because no project ID provided (no project file in current directory)
 */
ava_1.default.afterEach(() => {
    fetchMock.restore();
});
ava_1.default('Succeeding project clone with specific name', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mockData_1.mockedClonedProjectResponse));
    // create dummy project data
    const clonedProjectName = `Clone of MyProject`;
    const props = { name: clonedProjectName };
    // prepare environment
    const env = testEnvironment({});
    const projectFilePath = constants_1.graphcoolProjectFileName;
    env.resolver.write(projectFilePath, mockData_1.mockProjectFile1);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool clone -n "Clone of MyProject"`);
    yield t.notThrows(clone_1.default(props, env));
    const expectedProjectFileContent = mockData_1.clonedMockProjectFile1;
    const clonedProjectFileName = constants_1.graphcoolCloneProjectFileName(projectFilePath);
    t.is(env.resolver.read(clonedProjectFileName), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, clonedProjectFileName), 'nmlkjihgfedcba');
    t.is(file_1.readVersionFromProjectFile(env.resolver, clonedProjectFileName), '1');
}));
ava_1.default('Succeeding project clone with specific name and different output path', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mockData_1.mockedClonedProjectResponse));
    // create dummy project data
    const clonedProjectName = `Clone of MyProject`;
    const outputPath = `myclone.graphcool`;
    const props = { name: clonedProjectName, outputPath };
    // prepare environment
    const env = testEnvironment({});
    const projectFilePath = constants_1.graphcoolProjectFileName;
    env.resolver.write(projectFilePath, mockData_1.mockProjectFile1);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool clone -n "Clone of MyProject" -o ${outputPath}`);
    yield t.notThrows(clone_1.default(props, env));
    const expectedProjectFileContent = mockData_1.clonedMockProjectFile1;
    const clonedProjectFileName = outputPath;
    t.is(env.resolver.read(clonedProjectFileName), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, clonedProjectFileName), 'nmlkjihgfedcba');
    t.is(file_1.readVersionFromProjectFile(env.resolver, clonedProjectFileName), '1');
}));
ava_1.default('Succeeding project clone with specific name and project ID', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mockData_1.mockedClonedProjectResponse));
    // create dummy project data
    const clonedProjectName = `Clone of MyProject`;
    const sourceProjectId = `abcdefghijklmn`;
    const props = { name: clonedProjectName, sourceProjectId };
    // prepare environment
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool clone -n "Clone of MyProject" -s ${sourceProjectId}`);
    yield t.notThrows(clone_1.default(props, env));
    const expectedProjectFileContent = mockData_1.clonedMockProjectFile1;
    const clonedProjectFileName = constants_1.graphcoolCloneProjectFileName(constants_1.graphcoolProjectFileName);
    t.is(env.resolver.read(clonedProjectFileName), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, clonedProjectFileName), 'nmlkjihgfedcba');
    t.is(file_1.readVersionFromProjectFile(env.resolver, clonedProjectFileName), '1');
}));
ava_1.default('Succeeding project clone with specific name, project file and output path', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mockData_1.mockedClonedProjectResponse));
    // create dummy project data
    const clonedProjectName = `Clone of MyProject`;
    const projectFile = `example.graphcool`;
    const props = { name: clonedProjectName, projectFile };
    // prepare environment
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.resolver.write(projectFile, mockData_1.mockProjectFile1);
    env.out.prefix(t._test.title, `$ graphcool clone -n "Clone of MyProject" -p ${projectFile}`);
    yield t.notThrows(clone_1.default(props, env));
    // make sure the original project file wasn't overridden
    t.is(env.resolver.read(projectFile), mockData_1.mockProjectFile1);
    const expectedProjectFileContent = mockData_1.clonedMockProjectFile1;
    const clonedProjectFileName = constants_1.graphcoolCloneProjectFileName(projectFile);
    t.is(env.resolver.read(clonedProjectFileName), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, clonedProjectFileName), 'nmlkjihgfedcba');
    t.is(file_1.readVersionFromProjectFile(env.resolver, clonedProjectFileName), '1');
}));
ava_1.default('Failing because no project ID provided (no project file in current directory)', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mockData_1.mockedClonedProjectResponse));
    // create dummy project data
    const clonedProjectName = `Clone of MyProject`;
    const props = { name: clonedProjectName };
    // prepare environment
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool clone -n "Clone of MyProject"`);
    yield t.throws(clone(props, env));
}));
function clone(props, env) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield clone_1.default(props, env);
        }
        catch (e) {
            env.out.onError(e);
            throw e;
        }
    });
}
function testEnvironment(storage) {
    return {
        resolver: new TestResolver_1.default(storage),
        out: new TestOut_1.default(),
    };
}
//# sourceMappingURL=clone.test.js.map