"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const TestResolver_1 = require("../src/system/TestResolver");
const init_1 = require("../src/commands/init");
const constants_1 = require("../src/utils/constants");
const mockData_1 = require("./mock_data/mockData");
const schemas_1 = require("./mock_data/schemas");
require("isomorphic-fetch");
const file_1 = require("../src/utils/file");
const TestOut_1 = require("../src/system/TestOut");
const fetchMock = require('fetch-mock');
const debug = require('debug')('graphcool');
/*
 Tests:
 - Succeeding project creation with local schema file
 - Succeeding project creation with remote schema file
 - Succeeding project creation with local file and different output path
 - Succeeding project creation because with invalid output path, falls back to default
 - Succeeding project creation with alias
 */
ava_1.default.afterEach(() => {
    fetchMock.restore();
});
ava_1.default('Succeeding project creation with local schema file', (t) => __awaiter(this, void 0, void 0, function* () {
    const name = 'MyProject';
    const localSchemaFile = './myproject.graphql';
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mockData_1.mockedCreateProjectResponse));
    // create dummy project data
    const props = { name, localSchemaFile };
    // prepare environment
    const env = testEnvironment({});
    env.resolver.write(localSchemaFile, schemas_1.simpleTwitterSchema);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool init -f ${localSchemaFile} -n ${name}`);
    yield t.notThrows(init_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockProjectFile1;
    t.is(env.resolver.read(constants_1.graphcoolProjectFileName), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, constants_1.graphcoolProjectFileName), 'abcdefghijklmn');
    t.is(file_1.readVersionFromProjectFile(env.resolver, constants_1.graphcoolProjectFileName), '1');
}));
ava_1.default('Succeeding project creation with remote schema file', (t) => __awaiter(this, void 0, void 0, function* () {
    const name = 'MyProject';
    const remoteSchemaUrl = 'https://graphqlbin/project.graphql';
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mockData_1.mockedCreateProjectResponse));
    const schema = schemas_1.simpleTwitterSchema;
    fetchMock.get(remoteSchemaUrl, schema);
    // create dummy project data
    const props = { name, remoteSchemaUrl };
    // prepare environment
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool init -u ${remoteSchemaUrl} -n ${name}`);
    yield t.notThrows(init_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockProjectFile1;
    t.is(env.resolver.read(constants_1.graphcoolProjectFileName), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, constants_1.graphcoolProjectFileName), 'abcdefghijklmn');
    t.is(file_1.readVersionFromProjectFile(env.resolver, constants_1.graphcoolProjectFileName), '1');
}));
ava_1.default('Succeeding project creation with local file and different output path', (t) => __awaiter(this, void 0, void 0, function* () {
    const name = 'MyProject';
    const localSchemaFile = './myproject.graphql';
    const outputPath = '/Desktop/example.graphcool';
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mockData_1.mockedCreateProjectResponse));
    // create dummy project data
    const props = { name, localSchemaFile, outputPath };
    // prepare environment
    const env = testEnvironment({});
    env.resolver.write(localSchemaFile, schemas_1.simpleTwitterSchema);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool init -f ${localSchemaFile} -n ${name} -o ${outputPath}`);
    yield t.notThrows(init_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockProjectFile1;
    t.is(env.resolver.read(outputPath), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, outputPath), 'abcdefghijklmn');
    t.is(file_1.readVersionFromProjectFile(env.resolver, outputPath), '1');
}));
ava_1.default('Succeeding project creation because with invalid output path, falls back to default', (t) => __awaiter(this, void 0, void 0, function* () {
    const name = 'MyProject';
    const localSchemaFile = './myproject.graphql';
    const outputPath = '/Desktop/example.graphql';
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mockData_1.mockedCreateProjectResponse));
    // create dummy project data
    const props = { name, localSchemaFile, outputPath };
    // prepare environment
    const env = testEnvironment({});
    env.resolver.write(localSchemaFile, schemas_1.simpleTwitterSchema);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool init -f ${localSchemaFile} -n ${name} -o ${outputPath}`);
    yield t.notThrows(init_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockProjectFile1;
    t.is(env.resolver.read(constants_1.graphcoolProjectFileName), expectedProjectFileContent);
}));
ava_1.default('Succeeding project creation with alias', (t) => __awaiter(this, void 0, void 0, function* () {
    const name = 'MyProject';
    const localSchemaFile = './myproject.graphql';
    const alias = 'example';
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mockData_1.mockedCreateProjectResponseWithAlias));
    // create dummy project data
    const props = { name, alias, localSchemaFile };
    // prepare environment
    const env = testEnvironment({});
    env.resolver.write(localSchemaFile, schemas_1.simpleTwitterSchema);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool init -f ${localSchemaFile} -n ${name} -a ${alias}`);
    yield t.notThrows(init_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockProjectFileWithAlias1;
    t.is(env.resolver.read(constants_1.graphcoolProjectFileName), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, constants_1.graphcoolProjectFileName), alias);
    t.is(file_1.readVersionFromProjectFile(env.resolver, constants_1.graphcoolProjectFileName), '1');
}));
function testEnvironment(storage) {
    return {
        resolver: new TestResolver_1.default(storage),
        out: new TestOut_1.default(),
    };
}
//# sourceMappingURL=init.test.js.map