"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const TestResolver_1 = require("../src/system/TestResolver");
const pull_1 = require("../src/commands/pull");
const constants_1 = require("../src/utils/constants");
const mockData_1 = require("./mock_data/mockData");
const TestOut_1 = require("../src/system/TestOut");
require("isomorphic-fetch");
const fetchMock = require('fetch-mock');
const debug = require('debug')('graphcool');
/*
 Tests:
 - Pull without project file but passing project ID as argument
 - Pull without project file (defaulting to project.graphcoool)
 - Pull without project file (defaulting to project.graphcoool) updating version from 1 to 2
 - Pull without project file but passing project ID as argument, result has an alias
 - Pull without project file (defaulting to project.graphcoool) result has an alias, updating version from 1 to 2
 - Pull with specific project file, updating version from 1 to 2
 - Pull without project file (defaulting to project.graphcoool) and specify output path
 - Pull without project files but with multiple project files in current directory
 */
ava_1.default.afterEach(() => {
    fetchMock.restore();
});
ava_1.default('Pull without project file but passing project ID as argument', (t) => __awaiter(this, void 0, void 0, function* () {
    const sourceProjectId = 'cj26898xqm9tz0126n34d64ey';
    // configure HTTP mocks
    const mockedResponse = JSON.parse(mockData_1.mockedPullProjectResponse1);
    fetchMock.post(constants_1.systemAPIEndpoint, mockedResponse);
    // dummy pull data
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    const props = { force: true, sourceProjectId };
    env.out.prefix(t._test.title, `$ graphcool pull -s ${sourceProjectId}`);
    yield t.notThrows(pull_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockedPullProjectFile1;
    const result = env.resolver.read(constants_1.graphcoolProjectFileName);
    t.is(result, expectedProjectFileContent);
}));
ava_1.default('Pull without project file (defaulting to project.graphcoool)', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    const mockedResponse = JSON.parse(mockData_1.mockedPullProjectResponse1);
    fetchMock.post(constants_1.systemAPIEndpoint, mockedResponse);
    // dummy pull data
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    env.resolver.write(constants_1.graphcoolProjectFileName, mockData_1.mockedPullProjectFile1);
    const props = { force: true };
    env.out.prefix(t._test.title, `$ graphcool pull`);
    yield t.notThrows(pull_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockedPullProjectFile1;
    const result = env.resolver.read(constants_1.graphcoolProjectFileName);
    t.is(result, expectedProjectFileContent);
}));
ava_1.default('Pull without project file (defaulting to project.graphcoool) updating version from 1 to 2', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    const mockedResponse = JSON.parse(mockData_1.mockedPullProjectResponse2);
    fetchMock.post(constants_1.systemAPIEndpoint, mockedResponse);
    debug(`Mocked response: ${JSON.stringify(mockedResponse)}`);
    // dummy pull data
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    env.resolver.write(constants_1.graphcoolProjectFileName, mockData_1.mockedPullProjectFile1);
    const props = { force: true };
    env.out.prefix(t._test.title, `$ graphcool pull`);
    yield t.notThrows(pull_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockedPullProjectFile2;
    const result = env.resolver.read(constants_1.graphcoolProjectFileName);
    t.is(result, expectedProjectFileContent);
}));
ava_1.default('Pull without project file but passing project ID as argument, result has an alias', (t) => __awaiter(this, void 0, void 0, function* () {
    const sourceProjectId = 'cj26898xqm9tz0126n34d64ey';
    // configure HTTP mocks
    const mockedResponse = JSON.parse(mockData_1.mockedPullProjectResponseWithAlias1);
    debug(`Mock response: ${JSON.stringify(mockedResponse)}`);
    fetchMock.post(constants_1.systemAPIEndpoint, mockedResponse);
    // dummy pull data
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    const props = { force: true, sourceProjectId };
    env.out.prefix(t._test.title, `$ graphcool pull -s ${sourceProjectId}`);
    yield t.notThrows(pull_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockedPullProjectFileWithAlias1;
    const result = env.resolver.read(constants_1.graphcoolProjectFileName);
    t.is(result, expectedProjectFileContent);
}));
ava_1.default('Pull without project file (defaulting to project.graphcoool) result has an alias, updating version from 1 to 2', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    const mockedResponse = JSON.parse(mockData_1.mockedPullProjectResponseWithAlias2);
    fetchMock.post(constants_1.systemAPIEndpoint, mockedResponse);
    // dummy pull data
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    env.resolver.write(constants_1.graphcoolProjectFileName, mockData_1.mockedPullProjectFile1);
    const props = { force: true };
    env.out.prefix(t._test.title, `$ graphcool pull`);
    yield t.notThrows(pull_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockedPullProjectFileWithAlias2;
    const result = env.resolver.read(constants_1.graphcoolProjectFileName);
    t.is(result, expectedProjectFileContent);
}));
ava_1.default('Pull with specific project file, updating version from 1 to 2', (t) => __awaiter(this, void 0, void 0, function* () {
    const projectFile = '/Desktop/example.graphcool';
    // configure HTTP mocks
    const mockedResponse = JSON.parse(mockData_1.mockedPullProjectResponse2);
    fetchMock.post(constants_1.systemAPIEndpoint, mockedResponse);
    // dummy pull data
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    env.resolver.write(projectFile, mockData_1.mockedPullProjectFile1);
    const props = { force: true, projectFile };
    env.out.prefix(t._test.title, `$ graphcool pull -p ${projectFile}`);
    yield t.notThrows(pull_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockedPullProjectFile2;
    const result = env.resolver.read(projectFile);
    t.is(result, expectedProjectFileContent);
}));
ava_1.default('Pull without project file (defaulting to project.graphcoool) and specify output path', (t) => __awaiter(this, void 0, void 0, function* () {
    const outputPath = '/Desktop/example.graphcool';
    // configure HTTP mocks
    const mockedResponse = JSON.parse(mockData_1.mockedPullProjectResponse1);
    fetchMock.post(constants_1.systemAPIEndpoint, mockedResponse);
    // dummy pull data
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    env.resolver.write(constants_1.graphcoolProjectFileName, mockData_1.mockedPullProjectFile1);
    const props = { force: true, outputPath };
    env.out.prefix(t._test.title, `$ graphcool pull -o ${outputPath}`);
    yield t.notThrows(pull_1.default(props, env));
    const expectedProjectFileContent = mockData_1.mockedPullProjectFile1;
    const result = env.resolver.read(outputPath);
    t.is(result, expectedProjectFileContent);
}));
ava_1.default('Pull without project files but with multiple project files in current directory', (t) => __awaiter(this, void 0, void 0, function* () {
    const projectFile1 = 'example.graphcool';
    const projectFile2 = constants_1.graphcoolProjectFileName;
    const env = testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    env.resolver.write(projectFile1, mockData_1.mockedPullProjectFile1);
    env.resolver.write(projectFile2, mockData_1.mockedPullProjectFile1);
    const props = { force: true };
    env.out.prefix(t._test.title, `$ graphcool pull`);
    yield t.throws(pull(props, env));
    const expectedProjectFileContent1 = mockData_1.mockedPullProjectFile1;
    const expectedProjectFileContent2 = mockData_1.mockedPullProjectFile1;
    const result1 = env.resolver.read(projectFile1);
    const result2 = env.resolver.read(projectFile2);
    t.is(result1, expectedProjectFileContent1);
    t.is(result2, expectedProjectFileContent2);
}));
function pull(props, env) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield pull_1.default(props, env);
        }
        catch (e) {
            env.out.onError(e);
            throw e;
        }
    });
}
function testEnvironment(storage) {
    return {
        resolver: new TestResolver_1.default(storage),
        out: new TestOut_1.default(),
    };
}
//# sourceMappingURL=pull.test.js.map